@@ -1,6 +1,6 @@
 /*
 * morse_code.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2024 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -165,7 +165,7 @@ void morse_code::scale_tox (multi_curve& m, float tox) {
   point<float> vlast (m.vertices[last]);
 
   float factor = 1.0f;
-  if (vlast.x != 0); factor = tox / vlast.x;
+  if (vlast.x != 0) ; else factor = tox / vlast.x;
 
   for (int i = 0; i < n; ++i) {
 
