@@ -1,6 +1,6 @@
 /*
 * range.cc
-* DIN Is Noise is copyright (c) 2006-2021 Jagannathan Sampath
+* DIN Is Noise is copyright (c) 2006-2024 Jagannathan Sampath
 * DIN Is Noise is released under GNU Public License 2.0
 * For more information, please visit https://dinisnoise.org/
 */
@@ -46,16 +46,19 @@ void range::change_octave (int i, int o, scale_info& si) {
 	calc_note_freq (i, si);
 }
 
+void range::stamplabel (const string& lbl, int L, int B, int T/*, int w, int h*/) {
+  glColor3f (1, 1, 1);
+  draw_string (lbl, L, B);
+  draw_string (lbl, L, T);
+}
+
 void range::draw_labels (int label, int show_frequency) {
 
-  static float fr = 1.0f, fg = fr, fb = fr;
-  static float nr = 1, ng = nr, nb = nr;
-	static const int spc = 2;
+	int ln = line_height;
+  int L = extents.left, B = extents.bottom - ln, B2 = B - ln;
+  int R = extents.right, T = extents.top, T2 = T + ln;
 
-	int ln = line_height + spc;
-  int L = extents.left, B = extents.bottom - ln, B2 = B - ln, R = extents.right, T = extents.top + spc, T2 = T + ln;
-
-  glColor3f (fr, fg, fb);
+  glColor3f (1, 1, 1);
   pts[0]=L; pts[1]=extents.bottom;
   pts[2]=R; pts[3]=extents.bottom;
 	pts[4]=R; pts[5]=extents.top;
@@ -63,25 +66,20 @@ void range::draw_labels (int label, int show_frequency) {
 	glVertexPointer (2, GL_INT, 0, pts);
 	glDrawArrays (GL_LINE_LOOP, 0, 4);
 
-	glColor3f (nr, ng, nb);
 	string& n0 = notes[0].name;
-	draw_string (n0, L, B);
-	draw_string (n0, L, T);
+  stamplabel (n0, L, B, T);
+
 	if (show_frequency) {
 		string& h0 = notes[0].hz_name;
-		draw_string (h0, L, B2);
-		draw_string (h0, L, T2);
+    stamplabel (h0, L, B2, T2);
 	}
 
 	if (label == BOTH) {
 		string& n1 = notes[1].name; 
-		glColor3f (nr, ng, nb);
-		draw_string (n1, R, B);
-		draw_string (n1, R, T);
+    stamplabel (n1, R, B, T);
 		if (show_frequency) {
 			string& h1 = notes[1].hz_name;
-			draw_string (h1, R, B2);
-			draw_string (h1, R, T2);
+      stamplabel (h1, R, B2, T2);
 		}
 	}
 
@@ -116,4 +114,3 @@ void range::change_height (int dh) {
 void range::print_hz_per_pixel () {
 	cons << YELLOW << "Width = " << extents.width << " pixels, Hz/pixel = " << hz_per_pix () << eol;
 }
-
